/*
 * Project: MoleCuilder
 * Description: creates and alters molecular systems
 * Copyright (C)  2016 Frederik Heber. All rights reserved.
 *
 *
 *   This file is part of MoleCuilder.
 *
 *    MoleCuilder is free software: you can redistribute it and/or modify
 *    it under the terms of the GNU General Public License as published by
 *    the Free Software Foundation, either version 2 of the License, or
 *    (at your option) any later version.
 *
 *    MoleCuilder is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    GNU General Public License for more details.
 *
 *    You should have received a copy of the GNU General Public License
 *    along with MoleCuilder.  If not, see <http://www.gnu.org/licenses/>.
 */

/*
 * GridDownsampler.cpp
 *
 *  Created on: Jun 9, 2016
 *      Author: heber
 */


// include config.h
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "CodePatterns/MemDebug.hpp"

#include "GridDownsampler.hpp"

#include "CodePatterns/Log.hpp"

#include "Fragmentation/Summation/SetValues/SamplingGridProperties.hpp"

void GridDownsampler::downsample(
    const std::map<JobId_t, MPQCData> &_shortrangedata,
    const SamplingGridProperties &_domain,
    std::map<JobId_t, MPQCData> &_shortrangedata_downsampled
    )
{
  for (std::map<JobId_t, MPQCData>::const_iterator iter = _shortrangedata.begin();
      iter != _shortrangedata.end(); ++iter) {
    LOG(2, "INFO: Downsampling charge data from job " << iter->first);
    MPQCData downsampled(_domain);
    MPQCData::assignWithDownsampledGrid(downsampled, iter->second);
    _shortrangedata_downsampled.insert( std::make_pair( iter->first, downsampled ) );
  }
}
